@@ -305,6 +305,18 @@ def expand_item(item, shape):
     return tuple(expanded_item)
 
 
+def get_values_in_order(message, shape):
+    # type: (abc.Field, T.Tuple[int]) -> np.ndarray
+    # inform the data provider to return missing values as missing_value
+    values = message["values"]
+    if message.get("alternativeRowScanning", False):
+        values = values.copy().reshape(shape)
+        values[1::2, :] = values[1::2, ::-1]
+        return values.flatten()
+    else:
+        return values
+
+
 @attr.attrs(auto_attribs=True)
 class OnDiskArray:
     index: abc.Index[T.Any, abc.Field]
@@ -322,7 +334,7 @@ class OnDiskArray:
         for header_indexes, message_ids in self.field_id_index.items():
             # NOTE: fill a single field as found in the message
             message = self.index.get_field(message_ids[0])  # type: ignore
-            values = message["values"]
+            values = get_values_in_order(message, array[header_indexes].shape)
             array.__getitem__(header_indexes).flat[:] = values
         array[array == self.missing_value] = np.nan
         return array
@@ -340,7 +352,7 @@ class OnDiskArray:
                 continue
             # NOTE: fill a single field as found in the message
             message = self.index.get_field(message_ids[0])  # type: ignore
-            values = message["values"]
+            values = get_values_in_order(message, array_field[tuple(array_field_indexes)].shape)
             array_field.__getitem__(tuple(array_field_indexes)).flat[:] = values
 
         array = np.asarray(array_field[(Ellipsis,) + item[-self.geo_ndim :]])
@@ -363,7 +375,10 @@ GRID_TYPES_2D_NON_DIMENSION_COORDS = {
 
 
 def build_geography_coordinates(
-    first: abc.Field, encode_cf: T.Sequence[str], errors: str, log: logging.Logger = LOG,
+    first: abc.Field,
+    encode_cf: T.Sequence[str],
+    errors: str,
+    log: logging.Logger = LOG,
 ) -> T.Tuple[T.Tuple[str, ...], T.Tuple[int, ...], T.Dict[str, Variable]]:
     geo_coord_vars = {}  # type: T.Dict[str, Variable]
     grid_type = first["gridType"]
@@ -546,7 +561,7 @@ def build_variable_components(
 
                     extra_coords_data[coord_name][header_value] = coord_value
         offsets[tuple(header_indexes)] = message_ids
-    missing_value = data_var_attrs.get("missingValue", 9999)
+    missing_value = data_var_attrs.get("missingValue", messages.MISSING_VAUE_INDICATOR)
     on_disk_array = OnDiskArray(
         index=index,
         shape=shape,
@@ -558,7 +573,8 @@ def build_variable_components(
     if "time" in coord_vars and "step" in coord_vars:
         # add the 'valid_time' secondary coordinate
         time_dims, time_data = cfmessage.build_valid_time(
-            coord_vars["time"].data, coord_vars["step"].data,
+            coord_vars["time"].data,
+            coord_vars["step"].data,
         )
         attrs = COORD_ATTRS["valid_time"]
         coord_vars["valid_time"] = Variable(dimensions=time_dims, data=time_data, attributes=attrs)
