@@ -1,18 +1,18 @@
 import os
 import pathlib
 import typing as T
-from distutils.version import LooseVersion
 
 import numpy as np
 import xarray as xr
+from packaging.version import Version
 
-from . import abc, dataset, messages
-
-if LooseVersion(xr.__version__) <= "0.17.0":
+if Version(xr.__version__) <= Version("0.17.0"):
     raise ImportError("xarray_plugin module needs xarray version >= 0.18+")
 
 from xarray.backends.common import AbstractDataStore, BackendArray, BackendEntrypoint
 
+from . import abc, dataset, messages
+
 # FIXME: Add a dedicated lock, even if ecCodes is supposed to be thread-safe
 #   in most circumstances. See:
 #       https://confluence.ecmwf.int/display/ECC/Frequently+Asked+Questions
@@ -39,7 +39,10 @@ class CfGribDataStore(AbstractDataStore):
             opener = dataset.open_fieldset
         self.ds = opener(filename, **backend_kwargs)
 
-    def open_store_variable(self, var: dataset.Variable,) -> xr.Variable:
+    def open_store_variable(
+        self,
+        var: dataset.Variable,
+    ) -> xr.Variable:
         if isinstance(var.data, np.ndarray):
             data = var.data
         else:
@@ -68,7 +71,13 @@ class CfGribDataStore(AbstractDataStore):
 
 
 class CfGribBackend(BackendEntrypoint):
-    def guess_can_open(self, store_spec: str,) -> bool:
+    description = "Open GRIB files (.grib, .grib2, .grb and .grb2) in Xarray"
+    url = "https://github.com/ecmwf/cfgrib"
+
+    def guess_can_open(
+        self,
+        store_spec: str,
+    ) -> bool:
         try:
             _, ext = os.path.splitext(store_spec)
         except TypeError:
@@ -140,11 +149,17 @@ class CfGribArrayWrapper(BackendArray):
         self.dtype = array.dtype
         self.array = array
 
-    def __getitem__(self, key: xr.core.indexing.ExplicitIndexer,) -> np.ndarray:
+    def __getitem__(
+        self,
+        key: xr.core.indexing.ExplicitIndexer,
+    ) -> np.ndarray:
         return xr.core.indexing.explicit_indexing_adapter(
             key, self.shape, xr.core.indexing.IndexingSupport.BASIC, self._getitem
         )
 
-    def _getitem(self, key: T.Tuple[T.Any, ...],) -> np.ndarray:
+    def _getitem(
+        self,
+        key: T.Tuple[T.Any, ...],
+    ) -> np.ndarray:
         with self.datastore.lock:
             return self.array[key]
