@@ -22,6 +22,7 @@ import typing as T
 
 import xarray as xr
 
+from . import cfmessage, messages
 from .dataset import DatasetBuildError, open_fileindex
 
 LOGGER = logging.getLogger(__name__)
@@ -78,10 +79,12 @@ def open_variable_datasets(path, backend_kwargs={}, **kwargs):
     # type: (str, T.Dict[str, T.Any], T.Any) -> T.List[xr.Dataset]
     fileindex_kwargs = {
         key: backend_kwargs[key]
-        for key in ["filter_by_keys", "indexpath", "grib_errors"]
+        for key in ["filter_by_keys", "indexpath"]
         if key in backend_kwargs
     }
-    index = open_fileindex(path, **fileindex_kwargs)
+    errors = backend_kwargs.get("grib_errors", "warn")
+    stream = messages.FileStream(path, errors=errors)
+    index = open_fileindex(stream, computed_keys=cfmessage.COMPUTED_KEYS, **fileindex_kwargs)
     datasets = []  # type: T.List[xr.Dataset]
     for param_id in sorted(index["paramId"]):
         bk = backend_kwargs.copy()
